pygeodesy.namedTuples.Trilaterate5Tuple

Package pygeodesy :: Module namedTuples :: Class Trilaterate5Tuple |
[frames] | no frames]

# Class Trilaterate5Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       Trilaterate5Tuple

5-Tuple `(min, minPoint, max, maxPoint, n)` with `min` and `max` in `meter`, the corresponding trilaterated `minPoint` and `maxPoint` as `LatLon` and the number `n`. For area overlap, `min` and `max` are the smallest respectively largest overlap found. For perimeter intersection, `min` and `max` represent the closest respectively farthest intersection margin. Count `n` is the total number of trilaterated overlaps or intersections found, `0, 1, 2...6` with `0` meaning concentric.

See Also: The `ellipsoidalKarney-`, `ellipsoidalVincenty-` and `sphericalTrigonometry.LatLon.trilaterate5` method for further details on corner cases, like concentric or single trilaterated results.

Instance Methods
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`